//##########################################################################################################################
// Filename:
//   Timer.c
// Version:
//   000
// Letzte nderung:
//   00.00.0000
// Author:
//   Mm
// Modulbeschreibung:
//   Timer fr 1ms Systemtakt, Generierung Pulse und Zeiten
//   Verwendet wird der SysTick
//
//##########################################################################################################################

//**************************************************************************************************************************
// Eingebundene Dateien (includes)
//**************************************************************************************************************************

//******************** Eigene Dateien ********************
#include "Include.h"
#include "Timer_Task.h"

//**************************************************************************************************************************
// Definitionen von globalen Variablen
//**************************************************************************************************************************

// Impuls-Bits bei erreichen der Zeit:
// Die Bits werden im Interrupt nur gesetzt und mssen nach Verwendung im Task
// gelscht werden.
uintBit_T	tp1ms;		// Puls-Bits 1ms, Verwendung:
						// BIT0: Erzeugung Puls von 1000Hz
						// BIT1..15: Reserve
uintBit_T	tp10ms;		// Puls-Bits 10ms, Verwendung:
						// BIT0: Erzeugung Puls von 100Hz
						// BIT1..15: Reserve
uintBit_T	tp100ms;	// Puls-Bits 100ms, Verwendung:
						// BIT0: Erzeugung Puls von 10Hz
						// BIT1: Netz-Eingang
						// BIT2: Netz/Wechselrichter Eingang
						// BIT3..15: Reserve
uintBit_T	tp1s;		// Puls-Bits 1s, Verwendung:
						// BIT0: Erzeugung Puls von 1Hz
						// BIT1: LCD_Task fr Refresh-Impuls
						// BIT2: IIC Fehlerbehandlung
						// BIT3..15: Reserve
uintBit_T	tp1m;		// Puls-Bits 1m, Verwendung:
						// BIT0: Erzeugung Puls jede Minute
						// BIT1: Ofen_Calc()
						// BIT2..15: Reserve

unsigned char		tBlink;		// Blink-Frequenz 0,5 Hz
unsigned char		tPuls1m;	// Puls-Frequenz jede Minute
unsigned char		tPuls1s;	// Puls-Frequenz 1 Hz
unsigned char		tPuls100ms;	// Puls-Frequenz 10 Hz
unsigned char		tPuls10ms;	// Puls-Frequenz 100 Hz
unsigned char		tPuls1ms;	// Puls-Frequenz 1000 Hz

// Counter Variablen Freerun
int			tms;		// Counter der ms (0..999)
int			ts;			// Counter s (0..59)
int			tm;			// Counter Minute (0..32767)

int			tMainZyk;	// Anzahl der Main-Zyklen je Sekunde
int Timer_GetSysTickOld;

//**************************************************************************************************************************
// Funktionen
//**************************************************************************************************************************

//--------------------------------------------------------------------------------------------------------------------------
// Funktionsbeschreibung:
//   InitTimer - Initialisierung SysTick
// bergabe:
//  --
// Rckgabe:
//   --
//--------------------------------------------------------------------------------------------------------------------------
void Timer_TaskInit(void)
{
	SAVE_PC();
	SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK);
	// SysTick end of count event each 1ms with input clock equal to 8MHz (HCLK, default)
//	SysTick_Config(SystemCoreClock / 1000); // (8MHz / 1000) = 1ms
	SysTick_Config(8000); // (8MHz / 1000) = 1ms
	tMainZyk = 0;
	Timer_GetSysTickOld = 0;
}

// Task fr Puls-Generierung 1Hz und 10Hz
void Timer_Task(void)
{
	SAVE_PC();
	static int tMainZykM = 0;
	tMainZykM++;

	tPuls1ms = tp1ms.BIT0; // Erzeuge 1ms-Puls das fr einen Zyklus anstehend ist
	if (tPuls1ms) tp1ms.BIT0 = 0;
	tPuls10ms = tp10ms.BIT0; // Erzeuge 10ms-Puls das fr einen Zyklus anstehend ist
	if (tPuls10ms) tp10ms.BIT0 = 0;
	tPuls100ms = tp100ms.BIT0; // Erzeuge 100ms-Puls das fr einen Zyklus anstehend ist
	if (tPuls100ms) tp100ms.BIT0 = 0;
	tPuls1s = tp1s.BIT0; // Erzeuge 1s-Puls das fr einen Zyklus anstehend ist
	if (tPuls1s)
	{
		tp1s.BIT0 = 0;
		tMainZyk = tMainZykM;
		tMainZykM = 0;
	}
	tPuls1m = tp1m.BIT0; // Erzeuge 1-Minuten-Puls das fr einen Zyklus anstehend ist
	if (tPuls1m) tp1m.BIT0 = 0;
}

// Interrupt ms Timer
void Timer_Interrupt(void)
{
	SAVE_PC();
	// ms Zhler
	tms++;
	tms %= 1000;
	//Timer_GetSysTickOld = tms * 1000;
	tp1ms.WORD = 0xFFFF;	// Puls-Bits 1ms setzen
	if ((tms % 10) == 0) // 10 ms vergangen
	{
		tp10ms.WORD = 0xFFFF;	// Puls-Bits 10ms setzen
		if ((tms % 100) == 0) // 100 ms vergangen
		{
			tp100ms.WORD = 0xFFFF;	// Puls-Bits 100ms setzen
			if (tms == 0) // 1 s vergangen
			{
				tp1s.WORD = 0xFFFF;	// Puls-Bits 1s setzen
				ts++;		// Sekunde erhhen
				ts %= 60;
				tBlink = ts % 2; // Blinkfrequenz 0,5Hz erzeugen

				if (ts == 0)// Sekunde vorbei
				{
					tm++;	// Minute erhhen
					if (tm < 0)
						tm = 0;
					tp1m.WORD = 0xFFFF;	// Puls-Bits 1m setzen
				}
			}
		}
	}
}

// Lesen des System-Ticks, Rckgabe 0...999999 uS
// Diese Routine bercksichtigt den Interrupt-Aufruf und korrigiert selbststndig
int Timer_GetSysTick(void)
{
	SAVE_PC();
	int iMs1 = tms; // Zhlwert ms merken
	int iTick1 = ((6000 - SysTick->VAL) / 6); // 6000 = 6000 Zhler je ms
	int iMs2 = tms; // Zweiter Zhlwert ms merken
	if (iMs1 == iMs2) // Kein Interrupt whrend SysTick_GetCounter() abfrage?
		return iMs1 * 1000 + iTick1; // Rckgabe uS der aktuellen Sekunde
	return iMs2 * 1000 + ((6000 - SysTick->VAL) / 6); // Interrupt whrend SysTick_GetCounter(), daher erneut abfragen
}


