/*************************************************************************
 * Demo-Projekt, (c)2011 by Markus Mller, MmVisual
 * Dieser Code darf frei verwendet und modifiziert werden
 * Keine Garantie, Benutzung auf eigene Gefahr.
 *************************************************************************/

#include "Include.h"

//Declarations
int main(void);
void Sys_Init(void);
void Clk_Init(void);
void IO_InitApp(void);

/*************************************************************************
 * Function Name: main
 *************************************************************************/
int main(void)
{
	// Init system and clock
	Sys_Init(); // Dieser Aufruf MUSS zu Anfang stehen!
	Clk_Init(); // Erst danach hat die CPU die richtige Geschwindigkeit

	// Benutzerdefinierte INIts
    IO_InitApp();
    Timer_TaskInit();

	while(1)
	{
		Timer_Task();

		GPIO_WriteBit(GPIOA, GPIO_Pin_0, tBlink); // Port A.0 blinken lassen
		GPIO_WriteBit(GPIOC, GPIO_Pin_7, tBlink); // Port C.7 blinken lassen

		if (tBlink) // LEDs vom EVAL-Board "STM3210C-EVAL"
			GPIO_SetBits(GPIOD, GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_7 | GPIO_Pin_13);
		else GPIO_ResetBits(GPIOD, GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_7 | GPIO_Pin_13);
	}
	return 0;
}

/*************************************************************************
 * Function Name: Sys_Init
 * Initialiseren aller Variablen
 *************************************************************************/
void Sys_Init(void)
{
	NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0000);

	// Initialisieren Speicher, Variabken sind in der *.LD Datei deklariert
	extern unsigned long _etext;
	extern unsigned long _data;			/* start address for the .data section. defined in linker script */
	extern unsigned long _edata;		/* end address for the .data section. defined in linker script */
	extern unsigned long _bss;			/* start address for the .bss section. defined in linker script */
	extern unsigned long _ebss;			/* end address for the .bss section. defined in linker script */

	unsigned long *pulSrc, *pulDest;
	// Copy the data segment initializers from flash to SRAM.
	pulSrc = &_etext;
	for(pulDest = &_data; pulDest < &_edata; )
		*(pulDest++) = *(pulSrc++);
	// Zero fill the bss segment.
	for(pulDest = &_bss; pulDest < &_ebss; )
		*(pulDest++) = 0;
}

/*************************************************************************
 * Function Name: Clk_Init
 * Einrichten der CPU Geschwindigkeit
 * Derzeit aktiv: HSI mit 8MHZ ohne PLL
 *************************************************************************/
void Clk_Init (void)
{
	SAVE_PC();
    // Test Sys-Tick
	// Cloking the controller from internal HSI RC (8 MHz)
	RCC_HSICmd(ENABLE);
	// wait until the HSI is ready
	while(RCC_GetFlagStatus(RCC_FLAG_HSIRDY) == RESET);
	RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);
	// Init PLL
#define USE_PLL	0
	RCC_PLLCmd(DISABLE);
	SystemCoreClock = 8000000;	// Muss gesetzt werden, braucht die FW-LIB
#if USE_PLL
	RCC_PLLConfig(RCC_PLLSource_HSI_Div2, RCC_PLLMul_8); // PLLCLK = 8MHz * 4 = 32 MHz
	RCC_PLLCmd(ENABLE);
	while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
	RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
	while(RCC_GetSYSCLKSource() != 0x08);
	SystemCoreClock = 32000000;	// Muss gesetzt werden, braucht die FW-LIB
#endif
	// Set system clock divders
	RCC_HCLKConfig(RCC_SYSCLK_Div1);
	RCC_PCLK2Config(RCC_HCLK_Div1);
	RCC_PCLK1Config(RCC_HCLK_Div1);
	// Enable Prefetch Buffer
	FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);
	// Flash 0 wait state
    FLASH_SetLatency(FLASH_Latency_0);
	// Jetzt luft die CPU mit 8 MHz.

    NVIC_PriorityGroupConfig(NVIC_PriorityGroup_0);
}

// Konfiguration der IO-Signale, die nicht einem Modul angebunden sind
// Pins des Erweiterungsanschlusses werden als Input mit Pull-Up deklariert!
void IO_InitApp(void)
{
	SAVE_PC();

	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD, ENABLE);

    GPIO_InitTypeDef GPIO_InitSt;

	GPIO_InitSt.GPIO_Pin =  GPIO_Pin_0;	// Ausgang PA0
	GPIO_ResetBits(GPIOA, GPIO_InitSt.GPIO_Pin);
	GPIO_InitSt.GPIO_Mode = GPIO_Mode_Out_PP;
	GPIO_InitSt.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(GPIOA, &GPIO_InitSt);

	// LEDs vom EVAL-Board "STM3210C-EVAL"
	GPIO_InitSt.GPIO_Pin =  GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_7 | GPIO_Pin_13;	// Ausgang Port D
	GPIO_ResetBits(GPIOD, GPIO_InitSt.GPIO_Pin);
	GPIO_Init(GPIOD, &GPIO_InitSt);

	GPIO_InitSt.GPIO_Pin =  GPIO_Pin_7;	// Ausgang Port C
	GPIO_ResetBits(GPIOC, GPIO_InitSt.GPIO_Pin);
	GPIO_Init(GPIOC, &GPIO_InitSt);
}
